@@ -10,6 +10,7 @@ from simple_utils.core import (
     max_numbers,
     min_numbers,
     multiply_numbers,
+    multiply_three_numbers,
     print_message,
     square_numbers,
 )
@@ -553,3 +554,87 @@ class TestFormatCurrency:
 
         with pytest.raises(ValueError, match="Supported: USD, EUR, BRL, GBP"):
             format_currency(1000, "INVALID")
+
+
+class TestMultiplyThreeNumbers:
+    """Tests for the multiply_three_numbers function."""
+
+    def test_multiply_three_positive_integers(self):
+        """Test multiplying three positive integers."""
+        assert multiply_three_numbers(2, 3, 4) == 24
+        assert multiply_three_numbers(1, 1, 1) == 1
+        assert multiply_three_numbers(5, 2, 3) == 30
+
+    def test_multiply_three_positive_floats(self):
+        """Test multiplying three positive floats."""
+        assert multiply_three_numbers(2.0, 3.0, 4.0) == 24.0
+        assert multiply_three_numbers(1.5, 2.0, 3.0) == 9.0
+        assert multiply_three_numbers(0.5, 0.5, 0.5) == 0.125
+
+    def test_multiply_three_mixed_types(self):
+        """Test multiplying mixed int and float types."""
+        assert multiply_three_numbers(2, 3.0, 4) == 24.0
+        assert multiply_three_numbers(1.5, 2, 3) == 9.0
+        assert multiply_three_numbers(10, 0.1, 5) == 5.0
+
+    def test_multiply_three_with_zero(self):
+        """Test multiplying when one number is zero."""
+        assert multiply_three_numbers(0, 5, 10) == 0
+        assert multiply_three_numbers(2, 0, 8) == 0
+        assert multiply_three_numbers(3, 7, 0) == 0
+        assert multiply_three_numbers(0, 0, 0) == 0
+
+    def test_multiply_three_with_negative_numbers(self):
+        """Test multiplying with negative numbers."""
+        assert multiply_three_numbers(-2, 3, 4) == -24
+        assert multiply_three_numbers(2, -3, 4) == -24
+        assert multiply_three_numbers(2, 3, -4) == -24
+        assert multiply_three_numbers(-2, -3, 4) == 24
+        assert multiply_three_numbers(-2, -3, -4) == -24
+
+    def test_multiply_three_with_one(self):
+        """Test multiplying with the number one."""
+        assert multiply_three_numbers(1, 5, 3) == 15
+        assert multiply_three_numbers(7, 1, 2) == 14
+        assert multiply_three_numbers(4, 6, 1) == 24
+        assert multiply_three_numbers(1, 1, 5) == 5
+
+    def test_multiply_three_large_numbers(self):
+        """Test multiplying large numbers."""
+        assert multiply_three_numbers(1000, 1000, 1000) == 1000000000
+        assert multiply_three_numbers(999999, 1, 2) == 1999998
+
+    def test_multiply_three_small_numbers(self):
+        """Test multiplying small decimal numbers."""
+        result = multiply_three_numbers(0.1, 0.1, 0.1)
+        assert abs(result - 0.001) < 1e-10  # Handle floating point precision
+
+    def test_multiply_three_numbers_type_errors(self):
+        """Test that TypeError is raised for invalid input types."""
+        with pytest.raises(TypeError, match="Argument 'a' must be int or float"):
+            multiply_three_numbers("2", 3, 4)
+
+        with pytest.raises(TypeError, match="Argument 'b' must be int or float"):
+            multiply_three_numbers(2, "3", 4)
+
+        with pytest.raises(TypeError, match="Argument 'c' must be int or float"):
+            multiply_three_numbers(2, 3, "4")
+
+        with pytest.raises(TypeError, match="Argument 'a' must be int or float"):
+            multiply_three_numbers(None, 3, 4)
+
+        with pytest.raises(TypeError, match="Argument 'b' must be int or float"):
+            multiply_three_numbers(2, [], 4)
+
+        with pytest.raises(TypeError, match="Argument 'c' must be int or float"):
+            multiply_three_numbers(2, 3, {})
+
+    def test_multiply_three_numbers_edge_cases(self):
+        """Test edge cases and special values."""
+        # Very large numbers
+        result = multiply_three_numbers(1e10, 1e10, 1e10)
+        assert result == 1e30
+
+        # Very small numbers
+        result = multiply_three_numbers(1e-5, 1e-5, 1e-5)
+        assert abs(result - 1e-15) < 1e-20
